Obestavba Irys Exclusive (Výprodej)
Author: HS Flamingo s.r.o

Přeskočit na hlavní obsah / Přeskočit na doplňující obsah

X
Produkt byl přidán do objednávky.

Objednávky +420 491 422 647

Váš košík je prázdný

Přihlášení zákazníka

Přihlašovací jméno:

Vaše heslo:

Zapomněli jste heslo?

Úvod ZBOŽÍ V AKCI Obezdívky Obestavba Irys Exclusive (Akce)

Na porovnávací stránku »

# Obestavba Irys Exclusive (Akce)

Akce Doprava zdarma

Cena s DPH: | 21 777 Kč
Cena bez DPH: | 17 997 Kč
ks
Kód produktu: | HSF07-039
Dostupnost: | Skladem

- Rada odborníka
- Vytisknout stránku
- Upozornit známé

  Odeslat na e-mail

  - Facebook
  - Google
  - Twitter
  - Linkuj
  - Delicious
  - Jagg

ICO_INTERIER

## Detailní informace

Obestavba je určená k montáži s krbovou vložkou o standardních rozměrech s rovným sklem. Obestavba Irys má možnost nastavení šířky otvoru pro krbovou vložku v rozmezí 680-800mm a výšky v rozmezí 500-575 mm. Nastavitelné clony krbu vyrobené z granitu Nero Assoluto umožňují nastavení šíře otvoru pro krbovou vložku. Tento proces je prováděn bez řezání, broušení a prášení. Jednoduchá vestavba v případě montáže do rohu, či také na rovné stěně. Charakterizuje se možností rychlé a snadné montáže. Stejně tak nelze zaručit přesné zabarvení kamene tak, jak je to na obrázku.

Parametry obestavby Irys:
Jedná se jen o okrásný přírodní kámen
Čelní rám krbu je vyroben z přírodního kamene Nero Assoluto, ozdobeného dekorem ve vzoru "Manhattan".
Charakterizuje se možností rychlé a snadné montáže.

Jednotivé díly se k sobě lepí, nejsou potřeba žádné šrouby. Důkladně zkompletovaná obestavba, je neopakovatelným, nádherným a funkčním produktem, který zdobí prostory pokojů a salónů. Části obestavby jsou zabaleny v polystyrénu tak, aby nedošlo k poškození při přepravě.

Dekorativní zpracování zobrazených obestaveb se mohou lišit od obestaveb, které se nacházejí v prodeji. Přírodní kámen použitý pro obestavbu je jedinečným produktem a má charakteristické vlastnosti typické jen pro danou část materiálu. Proto nemůže být uznána eventuální reklamace z důvodu odstínu, skvrn, žilkování atp. Z důvodu ohraničených možností tiskařské techniky jsou prezentované odstíny obestaveb jen orientační.

## Technické informace

Leštěné části | granit NERO ASSOLUTO s dekorem “Manhattan”
Distributor pro ČR a SR | HS Flamingo s.r.o. - www.hsflamingo.cz

Nahoru

### Produkt ja zařazen v následujících kategoriích

- ZBOŽÍ V AKCI → Obezdívky

### Mohlo by vás také zajímat

- Ostatní |
- Biokrby |
- Kouřovody |
- Krbové mřížky |
- Příslušenství

Přeskočit na začátek stránky

© 2015, HS Flamingo s.r.o. – všechna práva vyhrazena

Prohlášení o přístupnosti | Mapa stránek

Webové stránky vytvořila eBRÁNA s.r.o. | E-shop vytvořen na Profesionální CMS | Výměna odkazů | XHTML 1.0

Tento eshop používá k poskytování služeb, personalizaci reklam a analýze návštěvnosti soubory cookie. Používáním tohoto webu s tím souhlasíte. Více informací Rozumím